pub struct CategoryScore {Show 14 fields
pub category: Category,
pub id: String,
pub name: String,
pub weight: f64,
pub note: String,
pub score: Option<f64>,
pub weighted_contribution: Option<f64>,
pub finding_count: usize,
pub enforced: usize,
pub present: usize,
pub partial: usize,
pub missing: usize,
pub unknown: usize,
pub not_applicable: usize,
}Expand description
Score for a single hygiene category.
Fields
category: Categoryid: Stringname: Stringweight: f64Rubric weight as a fraction of the overall score (e.g. 0.20 = 20%).
note: StringShort rubric rationale.
score: Option<f64>0–100 score (None when all findings are NotApplicable).
weighted_contribution: Option<f64>Contribution to overall score when this category participates (score * renormalized_weight).
finding_count: usizeenforced: usizepresent: usizepartial: usizemissing: usizeunknown: usizenot_applicable: usizeTrait Implementations
Sourceimpl Clone for CategoryScore
impl Clone for CategoryScore
Sourcefn clone(&self) -> CategoryScore
fn clone(&self) -> CategoryScore
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CategoryScore
impl Debug for CategoryScore
Sourceimpl<'de> Deserialize<'de> for CategoryScore
impl<'de> Deserialize<'de> for CategoryScore
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more